Index: src/parsing/parsing.h |
diff --git a/src/parsing/parsing.h b/src/parsing/parsing.h |
index 1f92c51838946af3944e560bf2a509c6217be030..3902377e0de0a576d187b8f3ad44a23116d7df54 100644 |
--- a/src/parsing/parsing.h |
+++ b/src/parsing/parsing.h |
@@ -16,16 +16,18 @@ namespace parsing { |
// Parses the top-level source code represented by the parse info and sets its |
// function literal. Returns false (and deallocates any allocated AST |
-// nodes) if parsing failed. |
-V8_EXPORT_PRIVATE bool ParseProgram(ParseInfo* info); |
+// nodes) if parsing failed. Internalizes AST nodes on the heap if |
+// |internalize|. |
+V8_EXPORT_PRIVATE bool ParseProgram(ParseInfo* info, bool internalize = true); |
-// Like ParseProgram but for an individual function. |
-V8_EXPORT_PRIVATE bool ParseFunction(ParseInfo* info); |
+// Like ParseProgram but for an individual function. Internalizes AST nodes on |
+// the heap if |internalize|. |
+V8_EXPORT_PRIVATE bool ParseFunction(ParseInfo* info, bool internalize = true); |
// If you don't know whether info->is_toplevel() is true or not, use this method |
// to dispatch to either of the above functions. Prefer to use the above methods |
-// whenever possible. |
-V8_EXPORT_PRIVATE bool ParseAny(ParseInfo* info); |
+// whenever possible. Internalizes AST nodes on the heap if |internalize|. |
+V8_EXPORT_PRIVATE bool ParseAny(ParseInfo* info, bool internalize = true); |
} // namespace parsing |
} // namespace internal |